==> multimedialib-2019.2.3-sources.jar: nl/colorize/multimedialib/renderer/teavm/TeaDemo.java <==
//-----------------------------------------------------------------------------
// Colorize MultimediaLib
// Copyright 2009-2020 Colorize
// Apache license (http://www.colorize.nl/code_license.txt)
//-----------------------------------------------------------------------------

package nl.colorize.multimedialib.renderer.teavm;

import nl.colorize.multimedialib.renderer.Canvas;
import nl.colorize.multimedialib.renderer.FilePointer;
import nl.colorize.multimedialib.scene.SceneManager;
import nl.colorize.multimedialib.tool.DemoApplication;

/**
 * Launcher for the TeaVM version of the demo application. This class will be
 * transpiled to JavaScript and then called from the browser.
 */
public class TeaDemo {

    private static final int CANVAS_WIDTH = 800;
    private static final int CANVAS_HEIGHT = 600;
    private static final boolean FLEXIBLE_CANVAS = true;
    private static final FilePointer VERIFICATION_FILE = new FilePointer("verification-instructions.txt");

    public static void main(String[] args) {
        Browser.log("MultimediaLib - TeaVM Demo");

        Canvas canvas = new Canvas(CANVAS_WIDTH, CANVAS_HEIGHT, FLEXIBLE_CANVAS);
        TeaRenderer renderer = new TeaRenderer(canvas);

        SceneManager sceneManager = SceneManager.attach(renderer);
        DemoApplication demo = new DemoApplication(renderer);
        sceneManager.changeScene(demo);

        String verificationInstructions = renderer.getMediaLoader().loadText(VERIFICATION_FILE);
        Browser.log(verificationInstructions);
    }
}

==> multimedialib-2020.2-sources.jar: nl/colorize/multimedialib/renderer/teavm/TeaDemo.java <==
//-----------------------------------------------------------------------------
// Colorize MultimediaLib
// Copyright 2009-2020 Colorize
// Apache license (http://www.apache.org/licenses/LICENSE-2.0)
//-----------------------------------------------------------------------------

package nl.colorize.multimedialib.renderer.teavm;

import nl.colorize.multimedialib.renderer.Canvas;
import nl.colorize.multimedialib.renderer.FilePointer;
import nl.colorize.multimedialib.scene.Application;
import nl.colorize.multimedialib.tool.DemoApplication;
import nl.colorize.util.Platform;

/**
 * Launcher for the TeaVM version of the demo application. This class will be
 * transpiled to JavaScript and then called from the browser.
 */
public class TeaDemo {

    private static final FilePointer VERIFICATION_FILE = new FilePointer("verification-instructions.txt");

    public static void main(String[] args) {
        Platform.enableTeaVM();

        Browser.log("MultimediaLib - TeaVM Demo");
        Browser.log("Screen size: " + Browser.getScreenWidth() + "x" + Browser.getScreenHeight());
        Browser.log("Page size: " + Browser.getPageWidth() + "x" + Browser.getPageHeight());

        Canvas canvas = Canvas.flexible(DemoApplication.DEFAULT_CANVAS_WIDTH,
            DemoApplication.DEFAULT_CANVAS_HEIGHT);
        TeaRenderer renderer = new TeaRenderer(canvas);

        Application app = new Application(renderer);
        DemoApplication demo = new DemoApplication(app);
        app.changeScene(demo);

        String verificationInstructions = renderer.getMediaLoader().loadText(VERIFICATION_FILE);
        Browser.log(verificationInstructions);
    }
}
